{% extends "base.html" %}

{% block content %}
<div class="card">
    <div class="card-header">
        <div class="card-icon">✓</div>
        <div>
            <h2 class="card-title">三角洲登录成功</h2>
            <p class="card-subtitle">账号已成功绑定</p>
        </div>
    </div>
    
    <div class="card-content">
        <div class="info-group">
            <div class="info-label">角色名</div>
            <div class="info-value">{{ user_name }}</div>
        </div>
        
        <div class="info-group">
            <div class="info-label">当前现金</div>
            <div class="info-value highlight">{{ money }}</div>
        </div>

        <div style="font-size: 12px; color: #9ca3af; margin-top: 8px; line-height: 1.6;">
            ⚠️ 有效期60天，在小程序登录会使当前登录状态失效
        </div>

    </div>
    
</div>
{% endblock %}