"""增加战场战绩播报功能

迁移 ID: dd1ba409cdcc
父迁移: 3fc264ad0bb7
创建时间: 2025-08-10 17:07:46.988033

"""
from __future__ import annotations

from collections.abc import Sequence

from alembic import op
import sqlalchemy as sa
from sqlalchemy import text


revision: str = 'dd1ba409cdcc'
down_revision: str | Sequence[str] | None = '3fc264ad0bb7'
branch_labels: str | Sequence[str] | None = None
depends_on: str | Sequence[str] | None = None


def upgrade(name: str = "") -> None:
    if name:
        return
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('nonebot_plugin_delta_helper_latestrecord', schema=None) as batch_op:
        batch_op.add_column(sa.Column('latest_tdm_record_id', sa.String(), nullable=False, server_default=text('temp')))

    # ### end Alembic commands ###


def downgrade(name: str = "") -> None:
    if name:
        return
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('nonebot_plugin_delta_helper_latestrecord', schema=None) as batch_op:
        batch_op.drop_column('latest_tdm_record_id')

    # ### end Alembic commands ###
