"""增加战绩播报个人开关

迁移 ID: 7baa1972cb66
父迁移: dd1ba409cdcc
创建时间: 2025-08-13 11:02:37.058380

"""
from __future__ import annotations

from collections.abc import Sequence

from alembic import op
import sqlalchemy as sa


revision: str = '7baa1972cb66'
down_revision: str | Sequence[str] | None = 'dd1ba409cdcc'
branch_labels: str | Sequence[str] | None = None
depends_on: str | Sequence[str] | None = None


def upgrade(name: str = "") -> None:
    if name:
        return
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('nonebot_plugin_delta_helper_userdata', schema=None) as batch_op:
        batch_op.add_column(sa.Column('if_broadcast_record', sa.Boolean(), server_default=sa.text('(true)'), nullable=False))

    # ### end Alembic commands ###


def downgrade(name: str = "") -> None:
    if name:
        return
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('nonebot_plugin_delta_helper_userdata', schema=None) as batch_op:
        batch_op.drop_column('if_broadcast_record')
    # ### end Alembic commands ###
